==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de Segurança</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de Sub-rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primário</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desabilitado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado, sem internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não conectado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autenticando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtendo endereço IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtendo endereço</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede via Cabo</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede via Cabo %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fio</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede sem fio %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desabilitado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não conectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado, sem internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>A conexão falhou</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desativar conexão cabeada</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ativar conexão cabeada</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desativar conexão Wi-Fi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ativar conexão Wi-Fi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configurações de rede</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.69.orig.tar.xz: dde-network-core-1.0.69/dock-network-plugin/translations/dock-network-plugin_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de Segurança</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de Sub-rede</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primário</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desabilitado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado, sem internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não conectado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autenticando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtendo endereço IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtendo endereço</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rede Cabeada</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rede Cabeada %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede Wi-Fi</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rede Wi-Fi %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo desabilitado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cabo de rede desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Não conectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado, sem internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>A conexão falhou</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desativar conexão cabeada</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Ativar conexão cabeada</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desativar conexão Wi-Fi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Ativar conexão Wi-Fi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desativar rede</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ativar rede</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configurações de rede</translation>
    </message>
</context>
</TS>
